@@ -1,12 +1,11 @@
 #' Cross-validation function for BTLLasso
 #' 
-#' Performs crossvalidation of BTLLasso, including the BTLLasso algorithm for
+#' Performs cross-validation of BTLLasso, including the BTLLasso algorithm for
 #' the whole data set.
 #' 
-#' Cross validation can be performed parallel, default is 10-fold cross
-#' validation on 10 cores. Output is a cv.BTLLasso object which can then be
-#' used for bootstrap confidence intervalls using \code{\link{boot.BTLLasso}}
-#' and \code{\link{ci.BTLLasso}}.
+#' Cross-validation can be performed parallel, default is 10-fold 
+#' cross-validation on 10 cores. Output is a cv.BTLLasso object which can then be
+#' used for bootstrap intervalls using \code{\link{boot.BTLLasso}}.
 #' 
 #' @param Y A \code{response.BTLLasso} object created by
 #' \code{\link{response.BTLLasso}}.
@@ -34,7 +33,8 @@
 #' matrix', Z.name, 'have to be equal to the subjects specified in the response
 #' object. Z2 has to be standardized.
 #' @param folds Number of folds for the crossvalidation. Default is 10.
-#' @param lambda Vector of tuning parameters.
+#' @param lambda Vector of tuning parameters. If \code{NULL}, automatically a grid
+#' of tuning parameters is created. 
 #' @param control Function for control arguments, mostly for internal use. See
 #' also \code{\link{ctrl.BTLLasso}}.
 #' @param cores Number of cores used for (parallelized) cross-validation. By
@@ -67,14 +67,16 @@
 #' one value per tuning parameter.}
 #' \item{folds}{Number of folds in cross validation.} 
 #' \item{cv.crit}{Cross-validation criterion, either \code{RPS} or \code{Deviance}.}
+#' \item{df}{Vector containing degrees of freedom for all models along the grid 
+#' of tuning parameters.}
 #' @author Gunther Schauberger\cr \email{gunther@@stat.uni-muenchen.de}\cr
-#' \url{http://www.statistik.lmu.de/~schauberger/}
+#' \url{http://www.semsto.statistik.uni-muenchen.de/personen/doktoranden/schauberger/index.html}
 #' @seealso \code{\link{BTLLasso}}, \code{\link{boot.BTLLasso}}, \code{\link{ctrl.BTLLasso}},
-#' \code{\link{singlepaths}}, \code{\link{paths}}
-#' @references Schauberger, Gunther and Tutz, Gerhard (2015): Modelling
-#' Heterogeneity in Paired Comparison Data - an L1 Penalty Approach with an
-#' Application to Party Preference Data, \emph{Department of Statistics, LMU
-#' Munich}, Technical Report 183
+#' \code{\link{plot.BTLLasso}}, \code{\link{paths}}, \code{\link{print.cv.BTLLasso}}, 
+#' \code{\link{predict.BTLLasso}}, \code{\link{coef}}
+#' @references Schauberger, Gunther and Tutz, Gerhard (2017): Subject-specific modelling 
+#' of paired comparison data: A lasso-type penalty approach, \emph{Statistical Modelling},
+#' 17(3), 223 - 243
 #' 
 #' Schauberger, Gunther, Groll Andreas and Tutz, Gerhard (2016): Modelling 
 #' Football Results in the German Bundesliga Using Match-specific Covariates, 
@@ -83,11 +85,12 @@
 #' @examples
 #' 
 #' \dontrun{
-#' ##### Example with simulated data set containing X, Z1 and Z2
-#' data(SimData)
+#' op <- par(no.readonly = TRUE)
 #' 
-#' ## Specify tuning parameters
-#' lambda <- exp(seq(log(151), log(1.05), length = 30)) - 1
+#' ##############################
+#' ##### Example with simulated data set containing X, Z1 and Z2
+#' ##############################
+#' data(SimData)
 #' 
 #' ## Specify control argument
 #' ## -> allow for object-specific order effects and penalize intercepts
@@ -95,31 +98,39 @@
 #'                       penalize.order.effect.diffs = TRUE)
 #' 
 #' ## Simple BTLLasso model for tuning parameters lambda
-#' m.sim <- BTLLasso(Y = SimData$Y, X = SimData$X, Z1 = SimData$Z1, 
-#'                   Z2 = SimData$Z2, lambda = lambda, control = ctrl)
-#' print(m.sim)
+#' m.sim <- BTLLasso(Y = SimData$Y, X = SimData$X, Z1 = SimData$Z1,
+#'                   Z2 = SimData$Z2, control = ctrl)
+#' m.sim
+#' 
+#' par(xpd = TRUE)
+#' plot(m.sim)
 #' 
-#' singlepaths(m.sim)
 #' 
 #' ## Cross-validate BTLLasso model for tuning parameters lambda
-#' set.seed(5)
-#' m.sim.cv <- cv.BTLLasso(Y = SimData$Y, X = SimData$X, Z1 = SimData$Z1, 
-#'                         Z2 = SimData$Z2, lambda = lambda, control = ctrl)
-#' print(m.sim.cv)
+#' set.seed(1860)
+#' m.sim.cv <- cv.BTLLasso(Y = SimData$Y, X = SimData$X, Z1 = SimData$Z1,
+#'                         Z2 = SimData$Z2, control = ctrl)
+#' m.sim.cv
+#' coef(m.sim.cv)
+#' logLik(m.sim.cv)
 #' 
-#' singlepaths(m.sim.cv, plot.order.effect = FALSE, 
-#'             plot.intercepts = FALSE, plot.Z2 = FALSE)
-#' paths(m.sim.cv, y.axis = 'L2')
+#' head(predict(m.sim.cv, type="response"))
+#' head(predict(m.sim.cv, type="trait"))
 #' 
-#' ## Example for bootstrap confidence intervals for illustration only
-#' ## Don't calculate bootstrap confidence intervals with B = 10!!!!
-#' set.seed(5)
-#' m.sim.boot <- boot.BTLLasso(m.sim.cv, B = 10, cores = 10)
-#' print(m.sim.boot)
-#' ci.BTLLasso(m.sim.boot)
+#' plot(m.sim.cv, plots_per_page = 4)
 #' 
 #' 
+#' ## Example for bootstrap intervals for illustration only
+#' ## Don't calculate bootstrap intervals with B = 20!!!!
+#' set.seed(1860)
+#' m.sim.boot <- boot.BTLLasso(m.sim.cv, B = 20, cores = 20)
+#' m.sim.boot
+#' plot(m.sim.boot, plots_per_page = 4)
+#' 
+#' 
+#' ##############################
 #' ##### Example with small version from GLES data set
+#' ##############################
 #' data(GLESsmall)
 #' 
 #' ## extract data and center covariates for better interpretability
@@ -130,27 +141,62 @@
 #' ## vector of subtitles, containing the coding of the X covariates
 #' subs.X <- c('', 'female (1); male (0)')
 #' 
-#' ## vector of tuning parameters
-#' lambda <- exp(seq(log(61), log(1), length = 30)) - 1
+#' ## Cross-validate BTLLasso model
+#' m.gles.cv <- cv.BTLLasso(Y = Y, X = X, Z1 = Z1)
+#' m.gles.cv
+#' 
+#' coef(m.gles.cv)
+#' logLik(m.gles.cv)
+#' 
+#' head(predict(m.gles.cv, type="response"))
+#' head(predict(m.gles.cv, type="trait"))
+#' 
+#' par(xpd = TRUE, mar = c(5,4,4,6))
+#' plot(m.gles.cv, subs.X = subs.X, plots_per_page = 4, which = 2:5)
+#' paths(m.gles.cv, y.axis = 'L2')
 #' 
 #' 
-#' ## compute BTLLasso model 
-#' m.gles <- BTLLasso(Y = Y, X = X, Z1 = Z1, lambda = lambda)
-#' print(m.gles)
+#' ##############################
+#' ##### Example with Bundesliga data set
+#' ##############################
+#' data(Buli1516)
 #' 
-#' singlepaths(m.gles, subs.X = subs.X)
-#' paths(m.gles, y.axis = 'L2')
+#' Y <- Buli1516$Y5
 #' 
-#' ## Cross-validate BTLLasso model 
-#' m.gles.cv <- cv.BTLLasso(Y = Y, X = X, Z1 = Z1, lambda = lambda)
-#' print(m.gles.cv)
+#' Z1 <- scale(Buli1516$Z1, scale = FALSE)
 #' 
-#' singlepaths(m.gles.cv, subs.X = subs.X)
+#' ctrl.buli <- ctrl.BTLLasso(object.order.effect = TRUE, 
+#'                            name.order = "Home", 
+#'                            penalize.order.effect.diffs = TRUE, 
+#'                            penalize.order.effect.absolute = FALSE,
+#'                            order.center = TRUE, lambda2 = 1e-2)
+#' 
+#' set.seed(1860)
+#' m.buli <- cv.BTLLasso(Y = Y, Z1 = Z1, control = ctrl.buli)
+#' m.buli
+#' 
+#' par(xpd = TRUE, mar = c(5,4,4,6))
+#' plot(m.buli)
+#' 
+#' 
+#' ##############################
+#' ##### Example with Topmodel data set
+#' ##############################
+#' data("Topmodel2007", package = "psychotree")
+#' 
+#' Y.models <- response.BTLLasso(Topmodel2007$preference)
+#' X.models <- scale(model.matrix(preference~., data = Topmodel2007)[,-1])
+#' rownames(X.models) <- paste0("Subject",1:nrow(X.models))
+#' colnames(X.models) <- c("Gender","Age","KnowShow","WatchShow","WatchFinal")
+#' 
+#' set.seed(5)
+#' m.models <- cv.BTLLasso(Y = Y.models, X = X.models)
+#' plot(m.models, plots_per_page = 6)
+#' 
+#' par(op)
 #' }
-#' 
-#' @export cv.BTLLasso
 cv.BTLLasso <- function(Y, X = NULL, Z1 = NULL, Z2 = NULL, folds = 10, 
-  lambda, control = ctrl.BTLLasso(), cores = folds, trace = TRUE, 
+  lambda = NULL, control = ctrl.BTLLasso(), cores = folds, trace = TRUE, 
   trace.cv = TRUE, cv.crit = c("RPS", "Deviance")) {
   
   cv.crit <- match.arg(cv.crit)
@@ -171,8 +217,9 @@ cv.BTLLasso <- function(Y, X = NULL, Z1 = NULL, Z2 = NULL, folds = 10,
   Y$subject.names <- levels(as.factor(Y$subject))
   Y$n <- length(Y$subject.names)
   
-  get.design$design <- get.design$design[!rep(na.total, each = Y$q), 
-    ]
+  get.design$design <- get.design$design[!rep(na.total, each = Y$q),]
+    
+  get.design$design.repar <- get.design$design.repar[!rep(na.total, each = Y$q),]
   
   ## create response vector
   if (Y$q == 1) {
@@ -184,29 +231,42 @@ cv.BTLLasso <- function(Y, X = NULL, Z1 = NULL, Z2 = NULL, folds = 10,
   get.penalties <- penalties.BTLLasso(Y = Y, X = X, Z1 = Z1, 
     Z2 = Z2, control = control)
   
+  ## create sequence of tuning parameters if not pre-specified
+  if(is.null(lambda)){
+    lambda <- find.lambda(response = response, 
+                          design = get.design$design, penalties = get.penalties, 
+                          k = Y$k, m = Y$m, control = control, trace = trace)
+  }
   
   fit <- fit.cv.BTLLasso(response = response, design = get.design$design, 
     penalty = get.penalties, q = Y$q, m = Y$m, folds = folds, 
     lambda = lambda, control = control, cores = cores, trace = trace, 
     trace.cv = trace.cv, cv.crit = cv.crit)
   
+  coefs <- fit$coefs
   
+  ## reparameterize coefficients, from reference object to
+  ## symmetric side constraint
+  coefs.repar <- round(expand.coefs(coefs, get.design, Y, name.order = control$name.order), 
+                       control$precision)
+  
+  
+  ## calculate log likelihood
   logLik <- c()
-  for (j in 1:nrow(fit$coefs)) {
-    logLik[j] <- loglik(fit$coefs[j, ], Y$response, get.design$design, 
-      Y$k)
+  for (j in 1:nrow(coefs)) {
+    logLik[j] <- loglik(coefs[j, ], Y$response, get.design$design, 
+                        Y$k)
   }
   
+  coefs <- round(coefs, control$precision)
   
-  coefs.repar <- round(expand.coefs(fit$coefs, get.design, 
-    Y), control$precision)
+  df <- df.BTLLasso(coefs.repar, get.design, Y$m)
   
-  
-  ret.list <- list(coefs = fit$coefs, coefs.repar = coefs.repar, 
+  ret.list <- list(coefs = coefs, coefs.repar = coefs.repar, 
     logLik = logLik, design = get.design, Y = Y, penalty = get.penalties, 
     response = response, X = X, Z1 = Z1, Z2 = Z2, lambda = lambda, 
     control = control, criterion = fit$criterion, folds = folds, 
-    cv.crit = cv.crit)
+    cv.crit = cv.crit, df = df)
   
   
   class(ret.list) <- c("cv.BTLLasso", "BTLLasso")
